# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/5/16


"""
吉尔吉斯语
"""

ACCURATE_REGEX_LIST = [
    r"(?P<bH>\d+)\s*саат мурда",
]

SUB_TRANSLATE = [

]
FUZZY_REGEX_LIST = []