# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/5/16

"""
俄语
"""

ACCURATE_REGEX_LIST = [
    r"(?P<bS>\d+)\s*секунда?\s*",
    r"(?P<bM>\d+)\s*минута?\s*",
    r"(?P<bH>\d+)\s*час?\s*",
]

SUB_TRANSLATE = [
    (r"январь", "1月"),
    (r"февраль", "2月"),
    (r"март", "3月"),
    (r"апрель|апреля|апрел", "4月"),
    (r"май", "5月"),
    (r"июнь|июня", "6月"),
    (r"июль|июля", "7月"),
    (r"август", "8月"),
    (r"сентябрь", "9月"),
    (r"октябрь", "10月"),
    (r"ноябрь", "11月"),
    (r"декабрь", "12月"),
    (r"сегодня  в|сегодня", "今天"),
    (r"вчера  в|вчера", "昨天"),
]
FUZZY_REGEX_LIST = []