# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/5/16

"""
土耳其语
"""

ACCURATE_REGEX_LIST = [
]

SUB_TRANSLATE = [
    (r"Nisan ", "4月"),
    (r"önce", "前"),
]

FUZZY_REGEX_LIST = [
    r"(?P<bM>\d+)\s*дақиқалар\s*аввал",
]
