# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/5/16


"""
印尼语
"""

ACCURATE_REGEX_LIST = [

]

SUB_TRANSLATE = [

]
FUZZY_REGEX_LIST = [
    r"(?P<bM>\d+)\s*jam\s*yang\s*lalu",
]