# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/5/16

"""
斯瓦希里语
"""

ACCURATE_REGEX_LIST = [
]

SUB_TRANSLATE = [
]

FUZZY_REGEX_LIST = [
    r"Saa\s*(?P<bH>\d+)\s*zilizopita\s*",
    r"Saa\s*(?P<bH>\d+)\s*iliyopita\s*",
    r"Dakika\s*(?P<bM>\d+)\s*zilizopita\s*",
]
